@@ -29,6 +29,7 @@ import os
 import shutil
 import tarfile
 import tempfile
+import traceback
 import zipfile
 import lzma
 
@@ -70,6 +71,9 @@ class FileUtil(object):
             bool: True if file exists or False otherwise
         """
         try:
+            if not locator:
+                logger.warning("Null locator: %s", "".join(traceback.format_stack()))
+                return False
             localFlag = self.isLocal(locator)
             if localFlag:
                 return os.access(locator, mode)
@@ -95,6 +99,9 @@ class FileUtil(object):
             int: approximate file size in bytes or zero
         """
         try:
+            if not locator:
+                logger.warning("Null locator: %s", "".join(traceback.format_stack()))
+                return False
             localFlag = self.isLocal(locator)
             if localFlag:
                 st = os.stat(locator)
@@ -193,6 +200,22 @@ class FileUtil(object):
         #
         return ok
 
+    def replace(self, srcPath, dstPath):
+        """Method to replace input file or directory (local only method)."""
+        ok = False
+        try:
+            localFlag = self.isLocal(srcPath)
+            if not localFlag:
+                return ok
+            if srcPath and dstPath and self.exists(srcPath):
+                os.replace(srcPath, dstPath)
+                ok = True
+        except Exception as e:
+            logger.error("Failing for %r -> %r with %s", srcPath, dstPath, str(e))
+            ok = False
+        #
+        return ok
+
     #
     def get(self, remote, local, **kwargs):
         """Fetch remote file to a local path.
