@@ -5,7 +5,7 @@
 try:
     from collections.abc import Mapping
 except ImportError:
-    from collections import Mapping
+    from collections import Mapping  # pylint: disable=deprecated-class
 
 
 class HashableDict(Mapping):
